@@ -1,6 +1,6 @@
  /***************************************************************************\
 |*                                                                           *|
-|*       Copyright 1993-2013 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2014 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NOTICE TO USER:   The source code  is copyrighted under  U.S. and     *|
 |*     international laws.  Users and possessors of this source code are     *|
@@ -11,7 +11,7 @@
 |*     tion and  internal comments to the code,  notices to the end user     *|
 |*     as follows:                                                           *|
 |*                                                                           *|
-|*       Copyright 1993-2013 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2014 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NVIDIA, CORPORATION MAKES NO REPRESENTATION ABOUT THE SUITABILITY     *|
 |*     OF  THIS SOURCE  CODE  FOR ANY PURPOSE.  IT IS  PROVIDED  "AS IS"     *|
@@ -130,9 +130,11 @@ typedef NvU8 NvBool;
 #define NV_TRUE           ((NvBool)(0 == 0))
 #define NV_FALSE          ((NvBool)(0 != 0))
 
-/* Tristate type: NV_TRUE, NV_FALSE, NV_INDETERMINATE */
+/* Tristate type: NV_TRISTATE_FALSE, NV_TRISTATE_TRUE, NV_TRISTATE_INDETERMINATE */
 typedef NvU8 NvTristate;
-#define NV_INDETERMINATE  ((NvTristate) 2)
+#define NV_TRISTATE_FALSE           ((NvTristate) 0)
+#define NV_TRISTATE_TRUE            ((NvTristate) 1)
+#define NV_TRISTATE_INDETERMINATE   ((NvTristate) 2)
 
 /* Macros to extract the low and high parts of a 64-bit unsigned integer */
 /* Also designed to work if someone happens to pass in a 32-bit integer */
