@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1999-2001 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1999-2013 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -152,6 +152,9 @@ NvBool      NV_API_CALL  os_is_xen_dom0              (void);
 NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
 RM_STATUS   NV_API_CALL  os_get_efi_screen_info      (NvU64 *, NvU32 *, NvU32 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
+RM_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
+RM_STATUS   NV_API_CALL  os_unlock_user_pages        (NvU64, void *);
+RM_STATUS   NV_API_CALL  os_match_mmap_offset        (void *, NvU64, NvU64 *);
 
 /*
  * ---------------------------------------------------------------------------
@@ -183,6 +186,9 @@ void NV_API_CALL  out_string(const char *str);
 int  NV_API_CALL  nv_printf(NvU32 debuglevel, const char *printf_format, ...);
 void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 
+/*
+ * those NV_MEMORY_* and NV_PROTECT_* have dup defines in osCore.h
+ */
 #define NV_MEMORY_TYPE_SYSTEM       0
 // #define NV_MEMORY_TYPE_AGP          1
 #define NV_MEMORY_TYPE_REGISTERS    2
@@ -204,9 +210,9 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define NV_PROTECT_WRITEABLE  2
 #define NV_PROTECT_READ_WRITE (NV_PROTECT_READABLE | NV_PROTECT_WRITEABLE)
 
-#define NV_FLUSH_USER_CACHE       1
-#define NV_INVALIDATE_USER_CACHE  2
-#define NV_FLUSH_INVALIDATE_USER_CACHE (NV_FLUSH_USER_CACHE | NV_INVALIDATE_USER_CACHE)
+#define OS_UNIX_FLUSH_USER_CACHE       1
+#define OS_UNIX_INVALIDATE_USER_CACHE  2
+#define OS_UNIX_FLUSH_INVALIDATE_USER_CACHE (OS_UNIX_FLUSH_USER_CACHE | OS_UNIX_INVALIDATE_USER_CACHE)
 
 /* in some cases, the os may have a different page size, but the
  * hardware (fb, regs, etc) still address and "think" in 4k
