@@ -91,6 +91,18 @@ typedef NvU32 RM_STATUS;
     ((_S) != RM_ERROR && (_S) & 0x00000100?     RM_STATUS_LEVEL_WARN:   \
                                                 RM_STATUS_LEVEL_ERR))
 
+/*!
+ * @def         RM_STATUS_LEVEL
+ * @see         RM_STATUS_LEVEL_OK
+ * @see         RM_STATUS_LEVEL_WARN
+ * @see         RM_STATUS_LEVEL_ERR
+ * @brief       Character representing status code level
+ */
+#define RM_STATUS_LEVEL_CHAR(_S)                        \
+    ((_S) == RM_OK?                             '0':    \
+    ((_S) != RM_ERROR && (_S) & 0x00000100?     'W':    \
+                                                'E'))
+
 
 #define RM_ERR_CANT_CREATE_CLASS_OBJS   0x00000001
 #define RM_ERR_DMA_IN_USE               0x00000002
